__version__ = '3.9.0'
__status__ = 'Development Status :: 5 - Production/Stable'
#__status__ = 'Development Status :: 4 - Beta'
__author__ = 'RicksLab'
__credits__ = ('Craig Echt - Testing, Debug, Verification, and Documentation',
               'Keith Myers - Testing, Debug, and Verification of NV Capability',
               '@berturion - Testing and Verification for Arch',
               '@Marjorie-R - Testing, Debug, and Verification for AMD-APU Capability',
               'Andrius Merkys - Debian Packaging',
               'Min Xu - Eliminate Gtk dependency for text gpu-mon option')
__required_pversion__ = (3, 6)
__required_kversion__ = (4, 8)
